<?php
/**
 * Contains all hook wrappers.
 */

function thesis_hook_before_html() {
	do_action('thesis_hook_before_html');
}

function thesis_hook_after_html() {
	do_action('thesis_hook_after_html');
}

function thesis_hook_before_header() {
	do_action('thesis_hook_before_header');
}

function thesis_hook_after_header() {
	do_action('thesis_hook_after_header');
}

function thesis_hook_header() {
	do_action('thesis_hook_header');
}

function thesis_hook_before_title() {
	do_action('thesis_hook_before_title');
}

function thesis_hook_after_title() {
	do_action('thesis_hook_after_title');
}

function thesis_hook_before_content_box() {
	do_action('thesis_hook_before_content_box');
}

function thesis_hook_after_content_box() {
	do_action('thesis_hook_after_content_box');
}

function thesis_hook_before_content() {
	do_action('thesis_hook_before_content');
}

function thesis_hook_after_content() {
	do_action('thesis_hook_after_content');
}

function thesis_hook_before_content_area() {
	do_action('thesis_hook_before_content_area');
}

function thesis_hook_after_content_area() {
	do_action('thesis_hook_after_content_area');
}

function thesis_hook_feature_box() {
	do_action('thesis_hook_feature_box');
}

function thesis_hook_before_post_box($post_count = false) {
	do_action('thesis_hook_before_post_box', $post_count);
}

function thesis_hook_after_post_box($post_count = false) {
	do_action('thesis_hook_after_post_box', $post_count);
}

function thesis_hook_before_teasers_box($post_count = false) {
	do_action('thesis_hook_before_teasers_box', $post_count);
}

function thesis_hook_after_teasers_box($post_count = false) {
	do_action('thesis_hook_after_teasers_box', $post_count);
}

function thesis_hook_before_post($post_count = false) {
	do_action('thesis_hook_before_post', $post_count);
}

function thesis_hook_after_post($post_count = false) {
	do_action('thesis_hook_after_post', $post_count);
}

function thesis_hook_before_teaser_box($post_count = false) {
	do_action('thesis_hook_before_teaser_box', $post_count);
}

function thesis_hook_after_teaser_box($post_count = false) {
	do_action('thesis_hook_after_teaser_box', $post_count);
}

function thesis_hook_before_teaser($post_count = false) {
	do_action('thesis_hook_before_teaser', $post_count);
}

function thesis_hook_after_teaser($post_count = false) {
	do_action('thesis_hook_after_teaser', $post_count);
}

function thesis_hook_before_headline($post_count = false) {
	do_action('thesis_hook_before_headline', $post_count);
}

function thesis_hook_after_headline($post_count = false) {
	do_action('thesis_hook_after_headline', $post_count);
}

function thesis_hook_before_teaser_headline($post_count = false) {
	do_action('thesis_hook_before_teaser_headline', $post_count);
}

function thesis_hook_after_teaser_headline($post_count = false) {
	do_action('thesis_hook_after_teaser_headline', $post_count);
}

function thesis_hook_byline_item($post_count = false) {
	do_action('thesis_hook_byline_item', $post_count);
}

function thesis_hook_before_comment_meta() {
	do_action('thesis_hook_before_comment_meta');
}

function thesis_hook_after_comment_meta() {
	do_action('thesis_hook_after_comment_meta');
}

function thesis_hook_after_comment() {
	do_action('thesis_hook_after_comment');
}

function thesis_hook_after_comments() {
	do_action('thesis_hook_after_comments');
}

function thesis_hook_comment_field() {
	do_action('thesis_hook_comment_field');
}

function thesis_hook_comment_form() {
	do_action('thesis_hook_comment_form');
}

function thesis_hook_archives_template() {
	do_action('thesis_hook_archives_template');
}

function thesis_hook_custom_template() {
	do_action('thesis_hook_custom_template');
}

function thesis_hook_faux_admin() {
	do_action('thesis_hook_faux_admin');
}

function thesis_hook_archive_info() {
	do_action('thesis_hook_archive_info');
}

function thesis_hook_404_title() {
	do_action('thesis_hook_404_title');
}

function thesis_hook_404_content() {
	do_action('thesis_hook_404_content');
}

function thesis_hook_before_sidebars() {
	do_action('thesis_hook_before_sidebars');
}

function thesis_hook_after_sidebars() {
	do_action('thesis_hook_after_sidebars');
}

function thesis_hook_multimedia_box() {
	do_action('thesis_hook_multimedia_box');
}

function thesis_hook_after_multimedia_box() {
	do_action('thesis_hook_after_multimedia_box');
}

function thesis_hook_before_sidebar_1() {
	do_action('thesis_hook_before_sidebar_1');
}

function thesis_hook_after_sidebar_1() {
	do_action('thesis_hook_after_sidebar_1');
}

function thesis_hook_before_sidebar_2() {
	do_action('thesis_hook_before_sidebar_2');
}

function thesis_hook_after_sidebar_2() {
	do_action('thesis_hook_after_sidebar_2');
}

function thesis_hook_before_footer() {
	do_action('thesis_hook_before_footer');
}

function thesis_hook_after_footer() {
	do_action('thesis_hook_after_footer');
}

function thesis_hook_footer() {
	do_action('thesis_hook_footer');
}